@echo OFF

SET app=menuApp
SET confedtr=maConfigEditor
SET mypath=%~dp0
SETLOCAL EnableDelayedExpansion

:: ****************************************************
:: Are we running as admin ?
::
fsutil dirty query %systemdrive% 1>nul 2>nul
SET NotAdmin=%ERRORLEVEL%

:: ****************************************************
:: If we are not Admin then:
::    tidy up, 
::    create a vbs script to promote this script to admin
::    run the vbs script, and hence this script as Admin
::    wait for vbs script to complete
::    run menuApp (not as Admin)
::    exit
::
:: If we are Admin then run the main body of the script
::
IF "%NotAdmin%" == "1" (
    IF EXIST "%tmp%\installdone.txt" DEL "%tmp%\installdone.txt"
    IF EXIST "%tmp%\getadmin.vbs" DEL "%tmp%\getadmin.vbs"

    echo Run install script as admin...

    ECHO Set UAC = CreateObject^("Shell.Application"^) : UAC.ShellExecute "cmd.exe", "/C title menuAppInstall && cd ""%~sdp0"" && ""%~s0"" %params% ", "", "runas", 1 > "%tmp%\getadmin.vbs"
    cscript /nologo "%tmp%\getadmin.vbs"

    TIMEOUT /T 2 1>nul

    echo Waiting for install to complete...

:Process-Running
    FOR /f "usebackq" %%i IN (`tasklist /NH /FI "WINDOWTITLE eq Administrator:  menuAppInstall*" ^| find /V "No tasks" ^| find /V /C ""`) DO SET TaskCount=%%i

    IF !TaskCount! GTR 0 (
      TIMEOUT /T 10 1>nul
      GOTO Process-Running
    )

    IF EXIST "%tmp%\installdone.txt" (
      echo Launch menuApp...
      start "" "%programfiles%\%app%\%app%.exe" -U
      DEL "%tmp%\installdone.txt"
    ) else (
      echo Install not completed...
    )

    echo Done...

    IF EXIST "%tmp%\getadmin.vbs" DEL "%tmp%\getadmin.vbs"

    TIMEOUT /T 2 1>nul

    exit /B
)

:: ****************************************************
:: Check if app is running
::
tasklist /FI "IMAGENAME eq %app%.exe" 2>NUL | find /I /N "%app%.exe">NUL
IF "%ERRORLEVEL%"=="0" GOTO Sub-CloseApp

:: ****************************************************
:: Check if config editor is running
::
tasklist /FI "IMAGENAME eq %confedtr%.exe" 2>NUL | find /I /N "%confedtr%.exe">NUL
IF "%ERRORLEVEL%"=="0" GOTO Sub-CloseConfigEditor

:: ****************************************************
:: Determine OS type (32 or 64 bit)
::
reg Query "HKLM\Hardware\Description\System\CentralProcessor\0" | find /i "x86" > NUL && set OS=32BIT || set OS=64BIT

:: ****************************************************
:: Pick up correct components for OS
::
IF %OS%==32BIT SET srcPath=%mypath%x86
IF %OS%==64BIT SET srcPath=%mypath%x64

:: ****************************************************
:: Copy (and overwrite) main files
::
xcopy "%srcPath%\*.*" "%programfiles%\%app%\" /Y

:: ****************************************************
:: Copy config if not already present
::
IF NOT EXIST "%LOCALAPPDATA%\menuApp\menuAppConfig.xml" xcopy %mypath%menuAppConfig.xml "%LOCALAPPDATA%\menuApp\"

:: ****************************************************
:: Create file to indicate that the install has been done
::

echo "" > "%tmp%\installdone.txt"

:: End of main processing
GOTO :End

:: ****************************************************************************************************
:Sub-CloseApp
  echo set WshShell = WScript.CreateObject("WScript.Shell") > %tmp%\tmp.vbs
  echo WScript.Quit (WshShell.Popup( "%app% is running. Please close it (ALT-X) and rerun the install script." ,100 ,"%app%-install", 0)) >> %tmp%\tmp.vbs
  cscript /nologo %tmp%\tmp.vbs
  del %tmp%\tmp.vbs
GOTO :EOF

:: ****************************************************************************************************
:Sub-CloseConfigEditor
  echo set WshShell = WScript.CreateObject("WScript.Shell") > %tmp%\tmp.vbs
  echo WScript.Quit (WshShell.Popup( "%app% Config Editor is running. Please close it (ALT-X) and rerun the install script." ,10 ,"%app%-install", 0)) >> %tmp%\tmp.vbs
  cscript /nologo %tmp%\tmp.vbs
  del %tmp%\tmp.vbs
GOTO :EOF

:: ****************************************************************************************************
:End